Money class

Represents a monetary value with currency.

Constructors

Money(double value, String currency)
Creates a Money instance.

Properties

currency String
The currency code (e.g., "USD", "EUR").
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The monetary value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited