isIncent property
Whether the channel was marked as giving the user an additional incentive to install the app.
Implementation
final bool isIncent;
Whether the channel was marked as giving the user an additional incentive to install the app.
final bool isIncent;