AttributionPartner class

A representation of the partner (network) the user was attributed to.

Constructors

AttributionPartner({required int id, required String name})
Creates an AttributionPartner instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
The unique identifier of the partner.
final
name String
The name of the partner.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited