Dimension class
Class containing all valid predefined dimension keys.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- jtAction → const String
- jtAdBundleId → const String
- jtAdInstanceName → const String
- jtAdNetwork → const String
- jtAdPlacement → const String
- jtAdSdk → const String
- jtAdSegment → const String
- jtAdTestGroup → const String
- jtAdUnit → const String
- jtCategory → const String
- jtContext → const String
- jtDetail → const String
- jtDuration → const String
- jtItemId → const String
- jtItemName → const String
- jtItemType → const String
- jtLocation → const String
- jtMethod → const String
- jtProductId → const String
- jtProductType → const String
- jtProgression1 → const String
- jtProgression2 → const String
- jtProgression3 → const String
- jtState → const String
- jtToken → const String
- jtTrigger → const String
- jtUnit → const String
- jtUrl → const String