JtAd class

You can use this event to capture details of an ad

Inheritance

Constructors

JtAd({required String jtAction, String? jtAdBundleId, String? jtAdInstanceName, String? jtAdNetwork, String? jtAdPlacement, String? jtAdSdk, String? jtAdSegment, String? jtAdUnit, String? jtAdTestGroup})
Creates a JtAd instance. @param jtAction Describes the action of the ad. @param jtAdBundleId The bundle id of the ad. @param jtAdInstanceName The instance name of the ad @param jtAdNetwork The ad network which served the advertisement. @param jtAdPlacement Information related to the placement of the advertisement @param jtAdSdk The SDK which served the advertisement. @param jtAdSegment The segment of the ad. @param jtAdUnit Type of advertisement. @param jtAdTestGroup The ad test group information.

Properties

dimensions Map<String, String>
The dimensions attached to this event.
finalinherited
eventName String
The name of the event.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited