JtLogin class

To capture all details related to user login events.

Inheritance

Constructors

JtLogin({required String jtAction, String? jtMethod})
Creates a JtLogin instance. @param jtAction Information about any action related to login. @param jtMethod Could be used to record login method.

Properties

dimensions Map<String, String>
The dimensions attached to this event.
finalinherited
eventName String
The name of the event.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited