JtProgression class

You can use this event to track all details related to the progression of the user in the game.

Inheritance

Constructors

JtProgression({required String jtAction, String? jtProgression1, String? jtProgression2, String? jtProgression3})
Creates a JtProgression instance. @param jtAction Defines the progression action. @param jtProgression1 Defines what kind of progression you're tracking. @param jtProgression2 Defines the step of the progression. @param jtProgression3 Defines some detail about the progression step.

Properties

dimensions Map<String, String>
The dimensions attached to this event.
finalinherited
eventName String
The name of the event.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited