AdUnit enum
All different ad unit types for ad impressions.
Values
-
Banner ad format.
const AdUnit('banner') - interstitial → const AdUnit
-
Interstitial ad format.
const AdUnit('interstitial') - rewarded → const AdUnit
-
Rewarded ad format.
const AdUnit('rewarded') - rewardedInterstitial → const AdUnit
-
Rewarded interstitial ad format.
const AdUnit('rewarded_interstitial') - appOpen → const AdUnit
-
App open ad format.
const AdUnit('app_open') - native_ → const AdUnit
-
Native ad format.
const AdUnit('native')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The encoded name used when communicating with native SDKs.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited