attribution library
Classes
- Attribution
- Attribution data returned by the justtrack backend.
- AttributionCampaign
- A representation of the campaign the user was attributed to.
- AttributionChannel
- A representation of the channel the user was attributed to.
- AttributionPartner
- A representation of the partner (network) the user was attributed to.