AttributionCampaign class
A representation of the campaign the user was attributed to.
Constructors
- AttributionCampaign({required int id, required String name, required String type, required bool isOrganic})
- Creates an AttributionCampaign instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
The unique identifier of the campaign.
final
- isOrganic → bool
-
Whether the campaign is an organic "campaign" (i.e., the user directly
installed from the app marketplace without seeing any ads).
final
- name → String
-
The name of the campaign.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of the campaign. Can be "acquisition" or "retargeting".
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited