AttributionChannel class
A representation of the channel the user was attributed to.
Constructors
- AttributionChannel({required int id, required String name, required bool isIncent})
- Creates an AttributionChannel instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
The unique identifier of the channel.
final
- isIncent → bool
-
Whether the channel was marked as giving the user an additional
incentive to install the app.
final
- name → String
-
The name of the channel.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited