events library
Classes
- AppEvent
- Base class for app events.
- JtAd
- You can use this event to capture details of an ad
- JtLogin
- To capture all details related to user login events.
- JtProgression
- You can use this event to track all details related to the progression of the user in the game.
- JtPurchase
- Event that tracks and reports in-app purchase related details
- JtResource
- You can use this event to capture details of items removed from the user's inventory.