AppEvent class abstract
Base class for app events.
Use this class to create custom events or use the predefined event classes like JtProgression, JtResource, JtPurchase, JtAd, and JtLogin.
- Implementers
Constructors
Properties
-
dimensions
→ Map<
String, String> -
The dimensions attached to this event.
final
- eventName → String
-
The name of the event.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited