JtPurchase class
Event that tracks and reports in-app purchase related details
Constructors
- JtPurchase({required String jtAction, required String jtProductId, String? jtToken, required String jtProductType})
- Creates a JtPurchase instance. @param jtAction Type of action. @param jtProductId Specifies the ID of the purchase or subscription. @param jtToken Specifies the token for the subscription purchase for validation on the backend. @param jtProductType Specify product type.
Properties
-
dimensions
→ Map<
String, String> -
The dimensions attached to this event.
finalinherited
- eventName → String
-
The name of the event.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited