JtResource class
You can use this event to capture details of items removed from the user's inventory.
Constructors
- JtResource({required String jtAction, String? jtItemType, String? jtItemName, String? jtItemId})
- Creates a JtResource instance. @param jtAction Indicates if the user's account or inventory was added or removed by something. @param jtItemType Use this dimension to categorize the item modified in the user's inventory. @param jtItemName Name of the item can be provided in this dimension. @param jtItemId ID of the item may be stored in this dimension.
Properties
-
dimensions
→ Map<
String, String> -
The dimensions attached to this event.
finalinherited
- eventName → String
-
The name of the event.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited