JtResource constructor
Creates a JtResource instance. @param jtAction Indicates if the user's account or inventory was added or removed by something. @param jtItemType Use this dimension to categorize the item modified in the user's inventory. @param jtItemName Name of the item can be provided in this dimension. @param jtItemId ID of the item may be stored in this dimension.
Implementation
JtResource({
required String jtAction,
String? jtItemType,
String? jtItemName,
String? jtItemId,
}) : super('jt_resource', {
'jt_action': jtAction,
if (jtItemType != null) 'jt_item_type': jtItemType,
if (jtItemName != null) 'jt_item_name': jtItemName,
if (jtItemId != null) 'jt_item_id': jtItemId,
});