JusttrackSdkPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- JusttrackSdkPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
anonymize(
) → Future< void> -
forwardAdImpression(
AdImpression impression) → Future< void> -
getAdvertiserIdInfo(
) → Future< AdvertiserIdInfo> -
getAttribution(
) → Future< Attribution> -
getInstallInstanceId(
) → Future< String> -
initializeSdk(
String apiToken, {bool manualStart = false, bool isLoggingEnabled = false, String? userId, String? serverUrl}) → Future< void> -
isRunning(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
track(
String event, [Map< String, String> ? dimensions]) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ JusttrackSdkPlatform
-
getter/setter pair